## 0.1.8
### REF accrete.contrib.ui.responses.table.TableResponse
Performance improvements

### IMP accrete.utils.views.page_from_querystring
Add parameter only: list[str] 

## 0.1.7
### ADD accrete.contrib.ui.responses.table.TableResponse.update_header
Returns an OobResponse for the table overview header

### ADD accrete.contrib.ui.templates.ui.layout.html
Event listener to set the primary table row, for use with hx-trigger.
E.g. ClientTrigger({"setPrimaryTableRow": "tr-14"})

## 0.1.6
### ADD accrete.contrib.ui.responses.table.TableResponse.update
Returns OobResponse for Table header and data for easier ui updates

### FIX accrete.contrib.ui.templates.ui.table.html
All fields displayed in footer on mobile

### REF accrete.contrib.ui.templates.ui.table_row_update.html
Changed swap to outerHTML

## 0.1.5
### REF accrete.contrib.ui.responses.response.Response
Parameter request of Response.render now defaults to None.

## 0.1.4
### IMP accrete.contrib.sequence.admin
Extend sequences list display

### IMP accrete.utils.forms
Display FormResult.save_error without error class

## 0.1.3
### IMP widgets/attrs.html
Set autocomplete to off by default on form fields if not set in widget attrs.

## 0.1.2
### ADD accrete.contrib.ui.responses.modal.ModalMessageResponse
UI Response to display simple messages.

### IMP accrete.contrib.ui.widgets.search_select
Dispatch 'input' event if values change.

## 0.1.1
### FIX accrete.contrib.ui.templatetags.ui.zero_trail
Only remove zeros if and after a decimal separator.
